"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.components import publicendpoint as components_publicendpoint
from openrouter.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class ListEndpointsZdrResponseTypedDict(TypedDict):
    r"""Returns a list of endpoints"""

    data: List[components_publicendpoint.PublicEndpointTypedDict]


class ListEndpointsZdrResponse(BaseModel):
    r"""Returns a list of endpoints"""

    data: List[components_publicendpoint.PublicEndpoint]
