"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import UnrecognizedStr
from typing import Literal, Union


OpenAIResponsesIncludable = Union[
    Literal[
        "file_search_call.results",
        "message.input_image.image_url",
        "computer_call_output.output.image_url",
        "reasoning.encrypted_content",
        "code_interpreter_call.outputs",
    ],
    UnrecognizedStr,
]
