"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from openrouter.utils import validate_const
import pydantic
from pydantic.functional_validators import AfterValidator
from typing import Literal
from typing_extensions import Annotated, TypedDict


class ResponseFormatTextGrammarTypedDict(TypedDict):
    grammar: str
    type: Literal["grammar"]


class ResponseFormatTextGrammar(BaseModel):
    grammar: str

    TYPE: Annotated[
        Annotated[Literal["grammar"], AfterValidator(validate_const("grammar"))],
        pydantic.Field(alias="type"),
    ] = "grammar"
