"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


OpenResponsesImageGenCallInProgressType = Literal[
    "response.image_generation_call.in_progress",
]


class OpenResponsesImageGenCallInProgressTypedDict(TypedDict):
    r"""Image generation call in progress"""

    type: OpenResponsesImageGenCallInProgressType
    item_id: str
    output_index: float
    sequence_number: float


class OpenResponsesImageGenCallInProgress(BaseModel):
    r"""Image generation call in progress"""

    type: OpenResponsesImageGenCallInProgressType

    item_id: str

    output_index: float

    sequence_number: float
