"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from typing_extensions import TypedDict


class CompletionUsageTypedDict(TypedDict):
    prompt_tokens: float
    completion_tokens: float
    total_tokens: float


class CompletionUsage(BaseModel):
    prompt_tokens: float

    completion_tokens: float

    total_tokens: float
