"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from openrouter.utils import validate_const
import pydantic
from pydantic.functional_validators import AfterValidator
from typing import Literal
from typing_extensions import Annotated, TypedDict


class ChatMessageToolCallFunctionTypedDict(TypedDict):
    name: str
    arguments: str


class ChatMessageToolCallFunction(BaseModel):
    name: str

    arguments: str


class ChatMessageToolCallTypedDict(TypedDict):
    id: str
    function: ChatMessageToolCallFunctionTypedDict
    type: Literal["function"]


class ChatMessageToolCall(BaseModel):
    id: str

    function: ChatMessageToolCallFunction

    TYPE: Annotated[
        Annotated[Literal["function"], AfterValidator(validate_const("function"))],
        pydantic.Field(alias="type"),
    ] = "function"
