"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import UnrecognizedStr
from typing import Literal, Union


OpenAIResponsesResponseStatus = Union[
    Literal[
        "completed",
        "incomplete",
        "in_progress",
        "failed",
        "cancelled",
        "queued",
    ],
    UnrecognizedStr,
]
