"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .responsesformatjsonobject import (
    ResponsesFormatJSONObject,
    ResponsesFormatJSONObjectTypedDict,
)
from .responsesformattext import ResponsesFormatText, ResponsesFormatTextTypedDict
from .responsesformattextjsonschemaconfig import (
    ResponsesFormatTextJSONSchemaConfig,
    ResponsesFormatTextJSONSchemaConfigTypedDict,
)
from typing import Union
from typing_extensions import TypeAliasType


ResponseFormatTextConfigTypedDict = TypeAliasType(
    "ResponseFormatTextConfigTypedDict",
    Union[
        ResponsesFormatTextTypedDict,
        ResponsesFormatJSONObjectTypedDict,
        ResponsesFormatTextJSONSchemaConfigTypedDict,
    ],
)
r"""Text response format configuration"""


ResponseFormatTextConfig = TypeAliasType(
    "ResponseFormatTextConfig",
    Union[
        ResponsesFormatText,
        ResponsesFormatJSONObject,
        ResponsesFormatTextJSONSchemaConfig,
    ],
)
r"""Text response format configuration"""
