"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import UnrecognizedStr
from typing import Literal, Union


OpenAIResponsesReasoningEffort = Union[
    Literal[
        "high",
        "medium",
        "low",
        "minimal",
    ],
    UnrecognizedStr,
]
