"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from typing_extensions import TypedDict


class GetCreditsResponseTypedDict(TypedDict):
    r"""Total credits purchased and used"""


class GetCreditsResponse(BaseModel):
    r"""Total credits purchased and used"""
