"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel, UnrecognizedStr
from openrouter.utils import validate_open_enum
from pydantic.functional_validators import PlainValidator
from typing import Literal, Optional, Union
from typing_extensions import Annotated, NotRequired, TypedDict


Reason = Union[
    Literal[
        "max_output_tokens",
        "content_filter",
    ],
    UnrecognizedStr,
]


class OpenAIResponsesIncompleteDetailsTypedDict(TypedDict):
    reason: NotRequired[Reason]


class OpenAIResponsesIncompleteDetails(BaseModel):
    reason: Annotated[Optional[Reason], PlainValidator(validate_open_enum(False))] = (
        None
    )
