"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


FilePathType = Literal["file_path",]


class FilePathTypedDict(TypedDict):
    type: FilePathType
    file_id: str
    index: float


class FilePath(BaseModel):
    type: FilePathType

    file_id: str

    index: float
