"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


ReasoningTextContentType = Literal["reasoning_text",]


class ReasoningTextContentTypedDict(TypedDict):
    type: ReasoningTextContentType
    text: str


class ReasoningTextContent(BaseModel):
    type: ReasoningTextContentType

    text: str
