"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .jsonschemaconfig import JSONSchemaConfig, JSONSchemaConfigTypedDict
from openrouter.types import BaseModel
from openrouter.utils import validate_const
import pydantic
from pydantic.functional_validators import AfterValidator
from typing import Literal
from typing_extensions import Annotated, TypedDict


class ResponseFormatJSONSchemaTypedDict(TypedDict):
    json_schema: JSONSchemaConfigTypedDict
    type: Literal["json_schema"]


class ResponseFormatJSONSchema(BaseModel):
    json_schema: JSONSchemaConfig

    TYPE: Annotated[
        Annotated[
            Literal["json_schema"], AfterValidator(validate_const("json_schema"))
        ],
        pydantic.Field(alias="type"),
    ] = "json_schema"
