"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .openairesponsesannotation import (
    OpenAIResponsesAnnotation,
    OpenAIResponsesAnnotationTypedDict,
)
from openrouter.types import BaseModel
from typing import List, Literal, Optional
from typing_extensions import NotRequired, TypedDict


ResponseOutputTextType = Literal["output_text",]


class ResponseOutputTextTypedDict(TypedDict):
    type: ResponseOutputTextType
    text: str
    annotations: NotRequired[List[OpenAIResponsesAnnotationTypedDict]]


class ResponseOutputText(BaseModel):
    type: ResponseOutputTextType

    text: str

    annotations: Optional[List[OpenAIResponsesAnnotation]] = None
