"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from openrouter.utils import validate_const
import pydantic
from pydantic.functional_validators import AfterValidator
from typing import Literal
from typing_extensions import Annotated, TypedDict


class VideoURLTypedDict(TypedDict):
    url: str


class VideoURL(BaseModel):
    url: str


class ChatMessageContentItemVideoTypedDict(TypedDict):
    video_url: VideoURLTypedDict
    type: Literal["input_video"]


class ChatMessageContentItemVideo(BaseModel):
    video_url: VideoURL

    TYPE: Annotated[
        Annotated[
            Literal["input_video"], AfterValidator(validate_const("input_video"))
        ],
        pydantic.Field(alias="type"),
    ] = "input_video"
