"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import UnrecognizedInt
from typing import Literal, Union


EndpointStatus = Union[
    Literal[
        0,
        -1,
        -2,
        -3,
        -5,
        -10,
    ],
    UnrecognizedInt,
]
