"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .reasoningsummarytext import ReasoningSummaryText, ReasoningSummaryTextTypedDict
from openrouter.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


OpenResponsesReasoningSummaryPartAddedEventType = Literal[
    "response.reasoning_summary_part.added",
]


class OpenResponsesReasoningSummaryPartAddedEventTypedDict(TypedDict):
    r"""Event emitted when a reasoning summary part is added"""

    type: OpenResponsesReasoningSummaryPartAddedEventType
    output_index: float
    item_id: str
    summary_index: float
    part: ReasoningSummaryTextTypedDict
    sequence_number: float


class OpenResponsesReasoningSummaryPartAddedEvent(BaseModel):
    r"""Event emitted when a reasoning summary part is added"""

    type: OpenResponsesReasoningSummaryPartAddedEventType

    output_index: float

    item_id: str

    summary_index: float

    part: ReasoningSummaryText

    sequence_number: float
