"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


URLCitationType = Literal["url_citation",]


class URLCitationTypedDict(TypedDict):
    type: URLCitationType
    url: str
    title: str
    start_index: float
    end_index: float


class URLCitation(BaseModel):
    type: URLCitationType

    url: str

    title: str

    start_index: float

    end_index: float
