"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .responsesimagegenerationcall import (
    ResponsesImageGenerationCall,
    ResponsesImageGenerationCallTypedDict,
)
from .responsesoutputitemfilesearchcall import (
    ResponsesOutputItemFileSearchCall,
    ResponsesOutputItemFileSearchCallTypedDict,
)
from .responsesoutputitemfunctioncall import (
    ResponsesOutputItemFunctionCall,
    ResponsesOutputItemFunctionCallTypedDict,
)
from .responsesoutputitemreasoning import (
    ResponsesOutputItemReasoning,
    ResponsesOutputItemReasoningTypedDict,
)
from .responsesoutputmessage import (
    ResponsesOutputMessage,
    ResponsesOutputMessageTypedDict,
)
from .responseswebsearchcalloutput import (
    ResponsesWebSearchCallOutput,
    ResponsesWebSearchCallOutputTypedDict,
)
from typing import Union
from typing_extensions import TypeAliasType


ResponsesOutputItemTypedDict = TypeAliasType(
    "ResponsesOutputItemTypedDict",
    Union[
        ResponsesWebSearchCallOutputTypedDict,
        ResponsesOutputItemFileSearchCallTypedDict,
        ResponsesImageGenerationCallTypedDict,
        ResponsesOutputMessageTypedDict,
        ResponsesOutputItemReasoningTypedDict,
        ResponsesOutputItemFunctionCallTypedDict,
    ],
)
r"""An output item from the response"""


ResponsesOutputItem = TypeAliasType(
    "ResponsesOutputItem",
    Union[
        ResponsesWebSearchCallOutput,
        ResponsesOutputItemFileSearchCall,
        ResponsesImageGenerationCall,
        ResponsesOutputMessage,
        ResponsesOutputItemReasoning,
        ResponsesOutputItemFunctionCall,
    ],
)
r"""An output item from the response"""
