"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .filecitation import FileCitation, FileCitationTypedDict
from .filepath import FilePath, FilePathTypedDict
from .urlcitation import URLCitation, URLCitationTypedDict
from typing import Union
from typing_extensions import TypeAliasType


OpenAIResponsesAnnotationTypedDict = TypeAliasType(
    "OpenAIResponsesAnnotationTypedDict",
    Union[FilePathTypedDict, FileCitationTypedDict, URLCitationTypedDict],
)


OpenAIResponsesAnnotation = TypeAliasType(
    "OpenAIResponsesAnnotation", Union[FilePath, FileCitation, URLCitation]
)
