"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


ResponseInputTextType = Literal["input_text",]


class ResponseInputTextTypedDict(TypedDict):
    r"""Text input content item"""

    type: ResponseInputTextType
    text: str


class ResponseInputText(BaseModel):
    r"""Text input content item"""

    type: ResponseInputTextType

    text: str
