"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


ReasoningSummaryTextType = Literal["summary_text",]


class ReasoningSummaryTextTypedDict(TypedDict):
    type: ReasoningSummaryTextType
    text: str


class ReasoningSummaryText(BaseModel):
    type: ReasoningSummaryTextType

    text: str
