"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


FileCitationType = Literal["file_citation",]


class FileCitationTypedDict(TypedDict):
    type: FileCitationType
    file_id: str
    filename: str
    index: float


class FileCitation(BaseModel):
    type: FileCitationType

    file_id: str

    filename: str

    index: float
