"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import UnrecognizedStr
from typing import Literal, Union


ChatCompletionFinishReason = Union[
    Literal[
        "tool_calls",
        "stop",
        "length",
        "content_filter",
        "error",
    ],
    UnrecognizedStr,
]
