"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


OpenResponsesReasoningDoneEventType = Literal["response.reasoning_text.done",]


class OpenResponsesReasoningDoneEventTypedDict(TypedDict):
    r"""Event emitted when reasoning text streaming is complete"""

    type: OpenResponsesReasoningDoneEventType
    output_index: float
    item_id: str
    content_index: float
    text: str
    sequence_number: float


class OpenResponsesReasoningDoneEvent(BaseModel):
    r"""Event emitted when reasoning text streaming is complete"""

    type: OpenResponsesReasoningDoneEventType

    output_index: float

    item_id: str

    content_index: float

    text: str

    sequence_number: float
