"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


ResponsesFormatJSONObjectType = Literal["json_object",]


class ResponsesFormatJSONObjectTypedDict(TypedDict):
    r"""JSON object response format"""

    type: ResponsesFormatJSONObjectType


class ResponsesFormatJSONObject(BaseModel):
    r"""JSON object response format"""

    type: ResponsesFormatJSONObjectType
