"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import UnrecognizedStr
from typing import Literal, Union


ModelGroup = Union[
    Literal[
        "Router",
        "Media",
        "Other",
        "GPT",
        "Claude",
        "Gemini",
        "Grok",
        "Cohere",
        "Nova",
        "Qwen",
        "Yi",
        "DeepSeek",
        "Mistral",
        "Llama2",
        "Llama3",
        "Llama4",
        "PaLM",
        "RWKV",
        "Qwen3",
    ],
    UnrecognizedStr,
]
r"""Tokenizer type used by the model"""
