"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .chatmessagecontentitemtext import (
    ChatMessageContentItemText,
    ChatMessageContentItemTextTypedDict,
)
from openrouter.types import BaseModel
from openrouter.utils import validate_const
import pydantic
from pydantic.functional_validators import AfterValidator
from typing import List, Literal, Optional, Union
from typing_extensions import Annotated, NotRequired, TypeAliasType, TypedDict


SystemMessageContentTypedDict = TypeAliasType(
    "SystemMessageContentTypedDict",
    Union[str, List[ChatMessageContentItemTextTypedDict]],
)


SystemMessageContent = TypeAliasType(
    "SystemMessageContent", Union[str, List[ChatMessageContentItemText]]
)


class SystemMessageTypedDict(TypedDict):
    content: SystemMessageContentTypedDict
    role: Literal["system"]
    name: NotRequired[str]


class SystemMessage(BaseModel):
    content: SystemMessageContent

    ROLE: Annotated[
        Annotated[Literal["system"], AfterValidator(validate_const("system"))],
        pydantic.Field(alias="role"),
    ] = "system"

    name: Optional[str] = None
