"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


ResponsesFormatTextType = Literal["text",]


class ResponsesFormatTextTypedDict(TypedDict):
    r"""Plain text response format"""

    type: ResponsesFormatTextType


class ResponsesFormatText(BaseModel):
    r"""Plain text response format"""

    type: ResponsesFormatTextType
