"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .websearchstatus import WebSearchStatus
from openrouter.types import BaseModel
from openrouter.utils import validate_open_enum
from pydantic.functional_validators import PlainValidator
from typing import List, Literal
from typing_extensions import Annotated, TypedDict


ResponsesOutputItemFileSearchCallType = Literal["file_search_call",]


class ResponsesOutputItemFileSearchCallTypedDict(TypedDict):
    type: ResponsesOutputItemFileSearchCallType
    id: str
    queries: List[str]
    status: WebSearchStatus


class ResponsesOutputItemFileSearchCall(BaseModel):
    type: ResponsesOutputItemFileSearchCallType

    id: str

    queries: List[str]

    status: Annotated[WebSearchStatus, PlainValidator(validate_open_enum(False))]
